@@ -1,4 +1,4 @@
-# Copyright (c) 2019, Riverbank Computing Limited
+# Copyright (c) 2020, Riverbank Computing Limited
 # All rights reserved.
 #
 # This copy of SIP is licensed for use under the terms of the SIP License
@@ -24,9 +24,10 @@
 from abc import ABC, abstractmethod
 import os
 import packaging
-from sipbuild import UserException
 import subprocess
 
+from sipbuild import UserException
+
 from .qt_metadata import VersionedMetadata
 from .verbose import verbose
 
@@ -54,7 +55,7 @@ class AbstractPackage(ABC):
         if self._qt_version < _min_qt_version:
             raise UserException("The version of Qt being bundled is too old")
 
-    def bundle_msvc_runtime(self, target_qt_dir):
+    def bundle_msvc_runtime(self, target_qt_dir, arch):
         """ Bundle the MSVC runtime. """
 
         # This default implementation does nothing.
@@ -64,7 +65,7 @@ class AbstractPackage(ABC):
 
         # This default implementation does nothing.
 
-    def bundle_qt(self, target_qt_dir, qt_dir, arch):
+    def bundle_qt(self, target_qt_dir, qt_dir, arch, exclude):
         """ Bundle the relevant parts of the Qt installation. """
 
         # Architecture-specific values.
@@ -84,6 +85,10 @@ class AbstractPackage(ABC):
         package_dir = os.path.dirname(target_qt_dir)
 
         for name, metadata in self.get_qt_metadata().items():
+            # Ignore a module if it is explicitly excluded.
+            if name in exclude:
+                continue
+
             for ext in module_extensions:
                 bindings = os.path.join(package_dir, name + ext)
 
